==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.osgi/src/com/openexchange/office/filter/osgi/FilterActivator.java <==
/*
 *
1 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.osgi;

import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.config.ConfigurationService;
import com.openexchange.jslob.JSlobService;
import com.openexchange.office.tools.osgi.ActivatorBase;

//=============================================================================
public class FilterActivator extends ActivatorBase
{
	//-------------------------------------------------------------------------   
    private static final String SERVICE_NAME = "com.openexchange.office.filter";

	//-------------------------------------------------------------------------   
    private static final Logger LOG = LoggerFactory.getLogger(FilterActivator.class);

	//-------------------------------------------------------------------------   
    public FilterActivator ()
        throws Exception
    {
    	super (SERVICE_NAME);
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void listMandatoryServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
    	lServices.add (ConfigurationService.class);
    	lServices.add (JSlobService        .class);
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void listOptionalServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
    	// no optional services
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void activate()
    	throws Exception
    {
        registerService(com.openexchange.office.filter.ooxml.docx.Importer.class, new com.openexchange.office.filter.ooxml.docx.Importer());
        registerService(com.openexchange.office.filter.ooxml.docx.Exporter.class, new com.openexchange.office.filter.ooxml.docx.Exporter());
        registerService(com.openexchange.office.filter.ooxml.pptx.Importer.class, new com.openexchange.office.filter.ooxml.pptx.Importer());
        registerService(com.openexchange.office.filter.ooxml.pptx.Exporter.class, new com.openexchange.office.filter.ooxml.pptx.Exporter());
        registerService(com.openexchange.office.filter.ooxml.xlsx.Importer.class, new com.openexchange.office.filter.ooxml.xlsx.Importer());
        registerService(com.openexchange.office.filter.ooxml.xlsx.Exporter.class, new com.openexchange.office.filter.ooxml.xlsx.Exporter());
        registerService(com.openexchange.office.filter.odf       .Importer.class, new com.openexchange.office.filter.odf       .Importer());
        registerService(com.openexchange.office.filter.odf       .Exporter.class, new com.openexchange.office.filter.odf       .Exporter());
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void deactivate()
    	throws Exception
    {
    	// de-registration of services is done by base class ...
    	// further actions not needed
    }
}

==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.filter.osgi/src/com/openexchange/office/filter/osgi/FilterActivator.java <==
/*
 *
1 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.osgi;

import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.config.ConfigurationService;
import com.openexchange.jslob.JSlobService;
import com.openexchange.office.tools.osgi.ActivatorBase;

//=============================================================================
public class FilterActivator extends ActivatorBase
{
	//-------------------------------------------------------------------------   
    private static final String SERVICE_NAME = "com.openexchange.office.filter";

	//-------------------------------------------------------------------------   
    private static final Logger LOG = LoggerFactory.getLogger(FilterActivator.class);

	//-------------------------------------------------------------------------   
    public FilterActivator ()
        throws Exception
    {
    	super (SERVICE_NAME);
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void listMandatoryServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
    	lServices.add (ConfigurationService.class);
    	lServices.add (JSlobService        .class);
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void listOptionalServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
    	// no optional services
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void activate()
    	throws Exception
    {
        registerService(com.openexchange.office.filter.ooxml.docx.Importer.class, new com.openexchange.office.filter.ooxml.docx.Importer());
        registerService(com.openexchange.office.filter.ooxml.docx.Exporter.class, new com.openexchange.office.filter.ooxml.docx.Exporter());
        registerService(com.openexchange.office.filter.ooxml.pptx.Importer.class, new com.openexchange.office.filter.ooxml.pptx.Importer());
        registerService(com.openexchange.office.filter.ooxml.pptx.Exporter.class, new com.openexchange.office.filter.ooxml.pptx.Exporter());
        registerService(com.openexchange.office.filter.ooxml.xlsx.Importer.class, new com.openexchange.office.filter.ooxml.xlsx.Importer());
        registerService(com.openexchange.office.filter.ooxml.xlsx.Exporter.class, new com.openexchange.office.filter.ooxml.xlsx.Exporter());
        registerService(com.openexchange.office.filter.ods.dom.Importer.class, new com.openexchange.office.filter.ods.dom.Importer());
        registerService(com.openexchange.office.filter.odp.dom.Importer.class, new com.openexchange.office.filter.odp.dom.Importer());
        registerService(com.openexchange.office.filter.odt.dom.Importer.class, new com.openexchange.office.filter.odt.dom.Importer());
        registerService(com.openexchange.office.filter.odf       .Exporter.class, new com.openexchange.office.filter.odf       .Exporter());
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void deactivate()
    	throws Exception
    {
    	// de-registration of services is done by base class ...
    	// further actions not needed
    }
}
